@@ -23,8 +23,8 @@ impl TealData for Example {
 fn test() {
     //create .d.tl file and compare against expected
     let file_contents = TypeWalker::new()
-        .process_type::<Example>(tealr::Direction::ToLua)
+        .process_type::<Example>()
         .generate_global("test")
         .expect("oh no :(");
-    assert_eq!(file_contents, "global record test\n\trecord Example\n\t\tuserdata\n\t\t-- Meta methods\n\t\tmetamethod __add: function(Example, integer):(Example)\n\n\tend\nend\nreturn test");
+    assert_eq!(file_contents, "global record test\n\trecord Example\n\t\tuserdata\n\n\t\t-- Meta methods\n\t\t__add: function(Example,integer):(Example)\n\n\n\tend\nend\nreturn test");
 }
